<?php
$page_title = "Confirm / Edit Your Profile";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href="/en/menu"><img src="../img/logo.png" alt="iWallet"></a></h1>
<?php include_once('template/base_sidebar_setting.php'); ?>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
						</div>
						<p class="pb20 respM">Confirm and continue.<br>
						KYC documents should be the same with your profile information. Please update your KYC documents if necessary.</p>
						<table class="table col bdr default odd settingT fontM mb30 ma90sp">
							<tr>
								<th>Email Address</th>
								<td><?php $this -> echoMail(); ?></td>
							</tr>
							<tr>
								<th>Password</th>
								<td>********</td>
							</tr>
							<tr>
								<th>First Name</th>
								<td><?php $this -> echoFirstName(); ?></td>
							</tr>
							<tr>
								<th>Last Name</th>
								<td><?php $this -> echolastName(); ?></td>
							</tr>
							<tr>
								<th>Date of Birth</th>
								<td><?php $this -> echoBirth(); ?></td>
							</tr>
							<tr>
								<th>Country</th>
								<td><?php $this -> echoCountry(); ?></td>
							</tr>
							<tr>
								<th>Region/State/Province</th>
								<td><?php $this -> echoState(); ?></td>
							</tr>
							<tr>
								<th>City</th>
								<td><?php $this -> echoCity(); ?></td>
							</tr>
							<tr>
								<th>Street</th>
								<td><?php $this -> echoAddress(); ?></td>
							</tr>
							<tr>
								<th>Post Code</th>
								<td><?php $this -> echoZipCode(); ?></td>
							</tr>
							<tr>
								<th>Phone Number</th>
								<td><?php $this -> echoTel(); ?></td>
							</tr>
						</table>
						<form id="acForm" action="" method="post">
							<input type="hidden" value="" id="type" name="type" />

							<input type="hidden" name="country" value="<?php echo $this -> getCountry(); ?>" />
							<input type="hidden" name="state" value="<?php $this -> echoState(); ?>" />
							<input type="hidden" name="city" value="<?php $this -> echoCity(); ?>" />
							<input type="hidden" name="address" value="<?php $this -> echoAddress(); ?>" />
							<input type="hidden" name="zip_code" value="<?php $this -> echoZipCode(); ?>" />
							<input type="hidden" name="tel" value="<?php $this -> echoTel(); ?>" />

							<input type="hidden" id="chicket_id" name="chicket_id" value="<?php echo $this -> createChicket();?>" />
						</form>
						<p class="">
							<a href="#" id="btnBack" class="btn bg-default calign">&laquo; Back</a>&emsp;
							<input type="button" id="btnComplete" value="Submit" class="btn bg-grad px180 calign">
						</p>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/setting.js"></script>
</body>
</html>
